
# Type: c1




URI: [ex:C1](http://example.org/mappings/C1)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[C1&#124;s1:string%20%3F;s2:identifier_type]^-[C3],%20[C1]^-[C2])

## Children

 * [C2](C2.md)
 * [C3](C3.md)

## Referenced by class


## Attributes


### Own

 * [s1](s1.md)  <sub>OPT</sub>
    * range: [String](types/String.md)
 * [s2](s2.md)  <sub>REQ</sub>
    * range: [IdentifierType](types/IdentifierType.md)

### Domain for slot:

 * [s1](s1.md)  <sub>OPT</sub>
    * range: [String](types/String.md)
 * [s2](s2.md)  <sub>REQ</sub>
    * range: [IdentifierType](types/IdentifierType.md)
